@@ -1,4 +1,4 @@
 from .client import QiwiWrapper
-from .qiwi_maps import QiwiMaps
+from .maps import QiwiMaps
 
 __all__ = ("QiwiWrapper", "QiwiMaps")
